@@ -79,14 +79,10 @@ extern "C" {
     int i, j, k, t, s, r, q, info, nProtect=0;
     const int inc = 1;
     const double one = 1.0;
-    const double negOne = -1.0;
     const double zero = 0.0;
     char const *lower = "L";
-    char const *upper = "U";
     char const *ntran = "N";
     char const *ytran = "T";
-    char const *rside = "R";
-    char const *lside = "L";
     
     /**********************************************************************
      * Get Inputs
@@ -127,8 +123,6 @@ extern "C" {
     int covModel = INTEGER(covModel_r)[0];
     std::string corName = getCorName(covModel);
     int J = INTEGER(J_r)[0];
-    int *JLong = INTEGER(JLong_r); 
-    int *K = INTEGER(K_r); 
     int *zLongIndx = INTEGER(zLongIndx_r); 
     int nObs = INTEGER(nObs_r)[0]; 
     // Rprintf("nObs: %i\n", nObs); 
@@ -245,20 +239,16 @@ extern "C" {
     double *tmp_pOcc = (double *) R_alloc(pOcc, sizeof(double));
     double *tmp_pDet2 = (double *) R_alloc(pDet, sizeof(double));
     double *tmp_pOcc2 = (double *) R_alloc(pOcc, sizeof(double));
-    double *tmp_one = (double *) R_alloc(1, sizeof(double)); 
-    double * tmp_JJ = (double *) R_alloc(JJ, sizeof(double)); 
     int *tmp_J = (int *) R_alloc(J, sizeof(int));
     for (j = 0; j < J; j++) {
       tmp_J[j] = zero; 
     }
-    double *tmp_nObs = (double *) R_alloc(nObs, sizeof(double)); 
     double *tmp_JpOcc = (double *) R_alloc(JpOcc, sizeof(double));
     double *tmp_nObspDet = (double *) R_alloc(nObspDet, sizeof(double));
     double *tmp_J1 = (double *) R_alloc(J, sizeof(double));
    
     // For latent occupancy
     double psiNum; 
-    double psiNew; 
     double *detProb = (double *) R_alloc(nObs, sizeof(double)); 
     double *psi = (double *) R_alloc(J, sizeof(double)); 
     zeros(psi, J); 
@@ -323,7 +313,7 @@ extern "C" {
     }  
     double *accept = (double *) R_alloc(nTheta, sizeof(double)); zeros(accept, nTheta); 
     double *theta = (double *) R_alloc(nTheta, sizeof(double));
-    double logMHRatio, logPostCurrent = 0.0, logPostCand = 0.0, detCand = 0.0, detCurr = 0.0;
+    double logPostCurrent = 0.0, logPostCand = 0.0;
     double logDet;  
     double phiCand = 0.0, nuCand = 0.0;  
     SEXP acceptSamples_r; 
