@@ -34,14 +34,10 @@ extern "C" {
     int i, j, k, s, a, b, q, r, info, nProtect=0;
     const int inc = 1;
     const double one = 1.0;
-    const double negOne = -1.0;
     const double zero = 0.0;
     char const *lower = "L";
-    char const *upper = "U";
     char const *ntran = "N";
     char const *ytran = "T";
-    char const *rside = "R";
-    char const *lside = "L";
     
     /**********************************************************************
      * Get Inputs
@@ -161,7 +157,6 @@ extern "C" {
       tmp_J[j] = 0; 
     }
     double *tmp_J1 = (double *) R_alloc(J, sizeof(double));
-    double *tmp_nObs = (double *) R_alloc(nObs, sizeof(double)); 
     double *tmp_JpOcc = (double *) R_alloc(JpOcc, sizeof(double));
     double *tmp_nObspDet = (double *) R_alloc(nObspDet, sizeof(double));
 
@@ -238,7 +233,6 @@ extern "C" {
    
     // For latent occupancy
     double psiNum; 
-    double psiNew; 
     double *detProb = (double *) R_alloc(nObsN, sizeof(double)); 
     double *psi = (double *) R_alloc(JN, sizeof(double)); 
     zeros(psi, JN); 
@@ -331,7 +325,6 @@ extern "C" {
     logPostCurr = R_NegInf; 
     double *accept = (double *) R_alloc(nThetaN, sizeof(double)); zeros(accept, nThetaN); 
     double phiCand = 0.0, nuCand = 0.0; 
-    double logDet; 
     // For sigmaSq Sampler
     double aSigmaSqPost = 0.0; 
     double bSigmaSqPost = 0.0; 
