@@ -83,14 +83,10 @@ extern "C" {
     int status = 0; // For AMCMC. 
     const int inc = 1;
     const double one = 1.0;
-    const double negOne = -1.0;
     const double zero = 0.0;
     char const *lower = "L";
-    char const *upper = "U";
     char const *ntran = "N";
     char const *ytran = "T";
-    char const *rside = "R";
-    char const *lside = "L";
 
     
     /**********************************************************************
@@ -253,7 +249,6 @@ extern "C" {
     double *tmp_pDet2 = (double *) R_alloc(pDet, sizeof(double));
     double *tmp_pOcc2 = (double *) R_alloc(pOcc, sizeof(double));
     double *tmp_one = (double *) R_alloc(1, sizeof(double)); 
-    double * tmp_JJ = (double *) R_alloc(JJ, sizeof(double)); 
     int *tmp_J = (int *) R_alloc(J, sizeof(int));
     for (j = 0; j < J; j++) {
       tmp_J[j] = zero; 
@@ -265,7 +260,6 @@ extern "C" {
    
     // For latent occupancy
     double psiNum; 
-    double psiNew; 
     double *detProb = (double *) R_alloc(nObs, sizeof(double)); 
     double *psi = (double *) R_alloc(J, sizeof(double)); 
     zeros(psi, J); 
@@ -320,7 +314,7 @@ extern "C" {
     }  
     double *accept = (double *) R_alloc(nTheta, sizeof(double)); zeros(accept, nTheta); 
     double *theta = (double *) R_alloc(nTheta, sizeof(double));
-    double logMHRatio, logPostCurrent = 0.0, logPostCand = 0.0, detCand = 0.0, detCurr = 0.0;
+    double logPostCurrent = 0.0, logPostCand = 0.0;
     double logDet;  
     double phiCand = 0.0, nuCand = 0.0;  
     SEXP acceptSamples_r; 
